/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_pkpass()
{
    qmlRegisterModule("org.kde.pkpass", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<BarcodeDerived>().id();
    qmlRegisterNamespaceAndRevisions(&BarcodeDerived::staticMetaObject, "org.kde.pkpass", 254, nullptr, &BarcodeDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<BarcodeForeign>("org.kde.pkpass", 254);
    QMetaType::fromType<BarcodeForeign *>().id();
    qmlRegisterEnum<KPkPass::Barcode::Format>("KPkPass::Barcode::Format");
    qmlRegisterTypesAndRevisions<BoardingPassForeign>("org.kde.pkpass", 254);
    QMetaType::fromType<BoardingPassForeign *>().id();
    qmlRegisterEnum<KPkPass::BoardingPass::TransitType>("KPkPass::BoardingPass::TransitType");
    qmlRegisterTypesAndRevisions<FieldForeign>("org.kde.pkpass", 254);
    QMetaType::fromType<FieldForeign *>().id();
    qmlRegisterTypesAndRevisions<PassForeign>("org.kde.pkpass", 254);
    QMetaType::fromType<PassForeign *>().id();
    qmlRegisterEnum<KPkPass::Pass::Type>("KPkPass::Pass::Type");
    qmlRegisterTypesAndRevisions<SeatForeign>("org.kde.pkpass", 254);
    QMetaType::fromType<SeatForeign *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.pkpass", 254, 254);
}

static const QQmlModuleRegistration orgkdepkpassRegistration("org.kde.pkpass", qml_register_types_org_kde_pkpass);
