/****************************************************************************
** Meta object code from reading C++ file 'field.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpkpass-26.07.80/src/field.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'field.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KPkPass5FieldE_t {};
} // unnamed namespace

template <> constexpr inline auto KPkPass::Field::qt_create_metaobjectdata<qt_meta_tag_ZN7KPkPass5FieldE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPkPass::Field",
        "key",
        "label",
        "value",
        "QVariant",
        "valueDisplayString",
        "changeMessage",
        "textAlignment",
        "Qt::Alignment",
        "currencyCode",
        "row",
        "isRichText"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'key'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'valueDisplayString'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'changeMessage'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'textAlignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currencyCode'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'row'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isRichText'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Field, qt_meta_tag_ZN7KPkPass5FieldE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPkPass::Field::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass5FieldE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass5FieldE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KPkPass5FieldE_t>.metaTypes,
    nullptr
} };

void KPkPass::Field::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Field *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->key(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->valueDisplayString(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->changeMessage(); break;
        case 5: *reinterpret_cast<Qt::Alignment*>(_v) = _t->textAlignment(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->currencyCode(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->row(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isRichText(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
