/****************************************************************************
** Meta object code from reading C++ file 'barcode.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpkpass-26.07.80/src/barcode.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'barcode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KPkPass7BarcodeE_t {};
} // unnamed namespace

template <> constexpr inline auto KPkPass::Barcode::qt_create_metaobjectdata<qt_meta_tag_ZN7KPkPass7BarcodeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPkPass::Barcode",
        "alternativeText",
        "format",
        "Format",
        "message",
        "messageEncoding",
        "Invalid",
        "QR",
        "PDF417",
        "Aztec",
        "Code128",
        "Code39",
        "Codabar",
        "EAN13",
        "I2of5"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alternativeText'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'format'
        QtMocHelpers::PropertyData<enum Format>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'messageEncoding'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Format'
        QtMocHelpers::EnumData<enum Format>(3, 3, QMC::EnumFlags{}).add({
            {    6, Format::Invalid },
            {    7, Format::QR },
            {    8, Format::PDF417 },
            {    9, Format::Aztec },
            {   10, Format::Code128 },
            {   11, Format::Code39 },
            {   12, Format::Codabar },
            {   13, Format::EAN13 },
            {   14, Format::I2of5 },
        }),
    };
    return QtMocHelpers::metaObjectData<Barcode, qt_meta_tag_ZN7KPkPass7BarcodeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPkPass::Barcode::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass7BarcodeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass7BarcodeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KPkPass7BarcodeE_t>.metaTypes,
    nullptr
} };

void KPkPass::Barcode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Barcode *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->alternativeText(); break;
        case 1: *reinterpret_cast<enum Format*>(_v) = _t->format(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->messageEncoding(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
