/****************************************************************************
** Meta object code from reading C++ file 'seat.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpkpass-26.07.80/src/seat.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'seat.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KPkPass4SeatE_t {};
} // unnamed namespace

template <> constexpr inline auto KPkPass::Seat::qt_create_metaobjectdata<qt_meta_tag_ZN7KPkPass4SeatE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPkPass::Seat",
        "asAirplaneSeat",
        "",
        "hasSeatAisle",
        "hasSeatLevel",
        "hasSeatNumber",
        "hasSeatRow",
        "hasSeatSection",
        "seatAisle",
        "seatLevel",
        "seatNumber",
        "seatRow",
        "seatSection"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'asAirplaneSeat'
        QtMocHelpers::MethodData<QString() const>(1, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasSeatAisle'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasSeatLevel'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasSeatNumber'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasSeatRow'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasSeatSection'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'seatAisle'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'seatLevel'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'seatNumber'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'seatRow'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'seatSection'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Seat, qt_meta_tag_ZN7KPkPass4SeatE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPkPass::Seat::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass4SeatE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass4SeatE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KPkPass4SeatE_t>.metaTypes,
    nullptr
} };

void KPkPass::Seat::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Seat *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->asAirplaneSeat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hasSeatAisle(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasSeatLevel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasSeatNumber(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasSeatRow(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasSeatSection(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->seatAisle(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->seatLevel(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->seatNumber(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->seatRow(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->seatSection(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
