/****************************************************************************
** Meta object code from reading C++ file 'pass.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpkpass-26.07.80/src/pass.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pass.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KPkPass4PassE_t {};
} // unnamed namespace

template <> constexpr inline auto KPkPass::Pass::qt_create_metaobjectdata<qt_meta_tag_ZN7KPkPass4PassE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPkPass::Pass",
        "icon",
        "QImage",
        "",
        "devicePixelRatio",
        "logo",
        "primaryLogo",
        "secondaryLogo",
        "strip",
        "background",
        "artwork",
        "footer",
        "thumbnail",
        "auxiliaryFieldsInRow",
        "QList<Field>",
        "row",
        "lookupMessage",
        "msg",
        "rawValue",
        "QJsonValue",
        "key",
        "type",
        "Type",
        "description",
        "organizationName",
        "passTypeIdentifier",
        "serialNumber",
        "expirationDate",
        "isVoided",
        "relevantDate",
        "hasBackgroundColor",
        "hasForegroundColor",
        "hasLabelColor",
        "backgroundColor",
        "QColor",
        "foregroundColor",
        "groupingIdentifier",
        "labelColor",
        "logoText",
        "hasIcon",
        "hasLogo",
        "hasPrimaryLogo",
        "hasSecondaryLogo",
        "hasStrip",
        "hasBackground",
        "hasArtwork",
        "hasFooter",
        "hasThumbnail",
        "preferredStyleSchemes",
        "hasBarcode",
        "barcodes",
        "QList<KPkPass::Barcode>",
        "auxiliaryFieldsRowCount",
        "auxiliaryFields",
        "QList<KPkPass::Field>",
        "backFields",
        "headerFields",
        "primaryFields",
        "secondaryFields",
        "locations",
        "QList<KPkPass::Location>",
        "field",
        "QVariantMap",
        "seats",
        "QList<KPkPass::Seat>",
        "semanticTags",
        "QJsonObject",
        "BoardingPass",
        "Coupon",
        "EventTicket",
        "Generic",
        "StoreCard"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'icon'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'icon'
        QtMocHelpers::MethodData<QImage() const>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'logo'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'logo'
        QtMocHelpers::MethodData<QImage() const>(5, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'primaryLogo'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'primaryLogo'
        QtMocHelpers::MethodData<QImage() const>(6, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'secondaryLogo'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(7, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'secondaryLogo'
        QtMocHelpers::MethodData<QImage() const>(7, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'strip'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'strip'
        QtMocHelpers::MethodData<QImage() const>(8, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'background'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'background'
        QtMocHelpers::MethodData<QImage() const>(9, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'artwork'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'artwork'
        QtMocHelpers::MethodData<QImage() const>(10, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'footer'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(11, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'footer'
        QtMocHelpers::MethodData<QImage() const>(11, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'thumbnail'
        QtMocHelpers::MethodData<QImage(unsigned int) const>(12, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Method 'thumbnail'
        QtMocHelpers::MethodData<QImage() const>(12, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Method 'auxiliaryFieldsInRow'
        QtMocHelpers::MethodData<QList<Field>(int) const>(13, 3, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 15 },
        }}),
        // Method 'lookupMessage'
        QtMocHelpers::MethodData<QString(const QString &) const>(16, 3, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'rawValue'
        QtMocHelpers::MethodData<QJsonValue(const QString &) const>(18, 3, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'organizationName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'passTypeIdentifier'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serialNumber'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'expirationDate'
        QtMocHelpers::PropertyData<QDateTime>(27, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isVoided'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'relevantDate'
        QtMocHelpers::PropertyData<QDateTime>(29, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasBackgroundColor'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasForegroundColor'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasLabelColor'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'foregroundColor'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'groupingIdentifier'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'labelColor'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'logoText'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasIcon'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasLogo'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasPrimaryLogo'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasSecondaryLogo'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasStrip'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasBackground'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasArtwork'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasFooter'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasThumbnail'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preferredStyleSchemes'
        QtMocHelpers::PropertyData<QStringList>(48, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasBarcode'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'barcodes'
        QtMocHelpers::PropertyData<QList<KPkPass::Barcode>>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'auxiliaryFieldsRowCount'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'auxiliaryFields'
        QtMocHelpers::PropertyData<QList<KPkPass::Field>>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backFields'
        QtMocHelpers::PropertyData<QList<KPkPass::Field>>(55, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'headerFields'
        QtMocHelpers::PropertyData<QList<KPkPass::Field>>(56, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'primaryFields'
        QtMocHelpers::PropertyData<QList<KPkPass::Field>>(57, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'secondaryFields'
        QtMocHelpers::PropertyData<QList<KPkPass::Field>>(58, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'locations'
        QtMocHelpers::PropertyData<QList<KPkPass::Location>>(59, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'field'
        QtMocHelpers::PropertyData<QVariantMap>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'seats'
        QtMocHelpers::PropertyData<QList<KPkPass::Seat>>(63, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'semanticTags'
        QtMocHelpers::PropertyData<QJsonObject>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(22, 22, QMC::EnumFlags{}).add({
            {   67, Type::BoardingPass },
            {   68, Type::Coupon },
            {   69, Type::EventTicket },
            {   70, Type::Generic },
            {   71, Type::StoreCard },
        }),
    };
    return QtMocHelpers::metaObjectData<Pass, qt_meta_tag_ZN7KPkPass4PassE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPkPass::Pass::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass4PassE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass4PassE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KPkPass4PassE_t>.metaTypes,
    nullptr
} };

void KPkPass::Pass::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Pass *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QImage _r = _t->icon((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 1: { QImage _r = _t->icon();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 2: { QImage _r = _t->logo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 3: { QImage _r = _t->logo();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 4: { QImage _r = _t->primaryLogo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 5: { QImage _r = _t->primaryLogo();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 6: { QImage _r = _t->secondaryLogo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 7: { QImage _r = _t->secondaryLogo();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 8: { QImage _r = _t->strip((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 9: { QImage _r = _t->strip();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 10: { QImage _r = _t->background((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 11: { QImage _r = _t->background();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 12: { QImage _r = _t->artwork((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 13: { QImage _r = _t->artwork();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 14: { QImage _r = _t->footer((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 15: { QImage _r = _t->footer();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 16: { QImage _r = _t->thumbnail((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 17: { QImage _r = _t->thumbnail();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 18: { QList<Field> _r = _t->auxiliaryFieldsInRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<Field>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->lookupMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QJsonValue _r = _t->rawValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJsonValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->organizationName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->passTypeIdentifier(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->serialNumber(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->expirationDate(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isVoided(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->relevantDate(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasBackgroundColor(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hasForegroundColor(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasLabelColor(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->foregroundColor(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->groupingIdentifier(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->labelColor(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->logoText(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->hasIcon(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->hasLogo(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->hasPrimaryLogo(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->hasSecondaryLogo(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->hasStrip(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->hasBackground(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->hasArtwork(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->hasFooter(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->hasThumbnail(); break;
        case 25: *reinterpret_cast<QStringList*>(_v) = _t->preferredStyleSchemes(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->hasBarcode(); break;
        case 27: *reinterpret_cast<QList<KPkPass::Barcode>*>(_v) = _t->barcodes(); break;
        case 28: *reinterpret_cast<int*>(_v) = _t->auxiliaryFieldsRowCount(); break;
        case 29: *reinterpret_cast<QList<KPkPass::Field>*>(_v) = _t->auxiliaryFields(); break;
        case 30: *reinterpret_cast<QList<KPkPass::Field>*>(_v) = _t->backFields(); break;
        case 31: *reinterpret_cast<QList<KPkPass::Field>*>(_v) = _t->headerFields(); break;
        case 32: *reinterpret_cast<QList<KPkPass::Field>*>(_v) = _t->primaryFields(); break;
        case 33: *reinterpret_cast<QList<KPkPass::Field>*>(_v) = _t->secondaryFields(); break;
        case 34: *reinterpret_cast<QList<KPkPass::Location>*>(_v) = _t->locations(); break;
        case 35: *reinterpret_cast<QVariantMap*>(_v) = _t->fieldsVariantMap(); break;
        case 36: *reinterpret_cast<QList<KPkPass::Seat>*>(_v) = _t->seats(); break;
        case 37: *reinterpret_cast<QJsonObject*>(_v) = _t->semanticTags(); break;
        default: break;
        }
    }
}

const QMetaObject *KPkPass::Pass::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPkPass::Pass::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPkPass4PassE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPkPass::Pass::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}
QT_WARNING_POP
