/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpkpass-26.07.80/src/quick/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PassForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PassForeign::qt_create_metaobjectdata<qt_meta_tag_ZN11PassForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PassForeign",
        "QML.Element",
        "Pass",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "KPkPass::Pass"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<PassForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PassForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PassForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PassForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PassForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19BoardingPassForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto BoardingPassForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19BoardingPassForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BoardingPassForeign",
        "QML.Element",
        "BoardingPass",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "QML.Foreign",
        "KPkPass::BoardingPass"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<BoardingPassForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BoardingPassForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BoardingPassForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BoardingPassForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19BoardingPassForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN12FieldForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto FieldForeign::qt_create_metaobjectdata<qt_meta_tag_ZN12FieldForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FieldForeign",
        "QML.Element",
        "field",
        "QML.Foreign",
        "KPkPass::Field"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FieldForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FieldForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12FieldForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12FieldForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12FieldForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14BarcodeForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto BarcodeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN14BarcodeForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BarcodeForeign",
        "QML.Element",
        "barcode",
        "QML.Foreign",
        "KPkPass::Barcode"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BarcodeForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BarcodeForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BarcodeForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BarcodeForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14BarcodeForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14BarcodeDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto BarcodeDerived::qt_create_metaobjectdata<qt_meta_tag_ZN14BarcodeDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BarcodeDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BarcodeDerived, qt_meta_tag_ZN14BarcodeDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BarcodeDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<KPkPass::Barcode>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BarcodeDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BarcodeDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14BarcodeDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11SeatForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto SeatForeign::qt_create_metaobjectdata<qt_meta_tag_ZN11SeatForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SeatForeign",
        "QML.Element",
        "seat",
        "QML.Foreign",
        "KPkPass::Seat"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SeatForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SeatForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SeatForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SeatForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SeatForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21BarcodeDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto BarcodeDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21BarcodeDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BarcodeDerivedForeign",
        "QML.Element",
        "Barcode",
        "QML.Foreign",
        "BarcodeDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN21BarcodeDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN21BarcodeDerivedForeignE =
    BarcodeDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21BarcodeDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN21BarcodeDerivedForeignE =
    qt_staticMetaObjectContent_ZN21BarcodeDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN21BarcodeDerivedForeignE =
    qt_staticMetaObjectContent_ZN21BarcodeDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject BarcodeDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN21BarcodeDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN21BarcodeDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN21BarcodeDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
